@@ -35,7 +35,7 @@ class RedisClient():
         # Clear the database if fresh_start is set to true
         if fresh_start:
             self.engine.flushdb()
-    
+
 
     def keys(self, pattern: str) -> list:
         """ Returns the keys that matches the pattern """
@@ -52,6 +52,21 @@ class RedisClient():
         return self.engine.keys("*")
 
 
+    def get_all_values(self) -> list:
+        """ Return all the available values """
+        return self.get_values_from_keys(self.get_all_keys())
+
+
+    def get_all_keys_values_as_dict(self) -> dict:
+        """ Returns the keys and values as a dictionary """
+        return dict(zip(self.get_all_keys(), self.get_all_values()))
+
+
+    def get_keys_values_as_dict(self, keys = list) -> dict:
+        """ Returns the keys and values as a dictionary """
+        return dict(zip(keys, self.get_values_from_keys(keys)))
+
+
     def get_values_from_keys(self, keys: list) -> list:
         """ Returns the values for the given keys """
         with self.engine.pipeline() as pipe:
